You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@tuscany.apache.org by rf...@apache.org on 2007/02/16 19:20:19 UTC

svn commit: r508527 - in /incubator/tuscany/branches/sca-java-integration/spec/sca-api-r1.0/src: main/java/org/osoa/sca/ main/java/org/osoa/sca/annotations/ test/java/org/osoa/sca/annotations/ test/java/sample/client/

Author: rfeng
Date: Fri Feb 16 10:20:18 2007
New Revision: 508527

URL: http://svn.apache.org/viewvc?view=rev&rev=508527
Log:
[sca-integration-branch] Merge SCA spec APIs from trunk

Added:
    incubator/tuscany/branches/sca-java-integration/spec/sca-api-r1.0/src/main/java/org/osoa/sca/Constants.java
      - copied unchanged from r508525, incubator/tuscany/java/spec/sca-api-r1.0/src/main/java/org/osoa/sca/Constants.java
    incubator/tuscany/branches/sca-java-integration/spec/sca-api-r1.0/src/main/java/org/osoa/sca/annotations/Confidentiality.java
      - copied unchanged from r508525, incubator/tuscany/java/spec/sca-api-r1.0/src/main/java/org/osoa/sca/annotations/Confidentiality.java
    incubator/tuscany/branches/sca-java-integration/spec/sca-api-r1.0/src/main/java/org/osoa/sca/annotations/Intent.java
      - copied unchanged from r508525, incubator/tuscany/java/spec/sca-api-r1.0/src/main/java/org/osoa/sca/annotations/Intent.java
    incubator/tuscany/branches/sca-java-integration/spec/sca-api-r1.0/src/main/java/org/osoa/sca/annotations/Qualifier.java
      - copied unchanged from r508525, incubator/tuscany/java/spec/sca-api-r1.0/src/main/java/org/osoa/sca/annotations/Qualifier.java
    incubator/tuscany/branches/sca-java-integration/spec/sca-api-r1.0/src/test/java/org/osoa/sca/annotations/ConfidentialImpl.java
      - copied unchanged from r508525, incubator/tuscany/java/spec/sca-api-r1.0/src/test/java/org/osoa/sca/annotations/ConfidentialImpl.java
Modified:
    incubator/tuscany/branches/sca-java-integration/spec/sca-api-r1.0/src/main/java/org/osoa/sca/RequestContext.java
    incubator/tuscany/branches/sca-java-integration/spec/sca-api-r1.0/src/test/java/sample/client/BasicClient.java

Modified: incubator/tuscany/branches/sca-java-integration/spec/sca-api-r1.0/src/main/java/org/osoa/sca/RequestContext.java
URL: http://svn.apache.org/viewvc/incubator/tuscany/branches/sca-java-integration/spec/sca-api-r1.0/src/main/java/org/osoa/sca/RequestContext.java?view=diff&rev=508527&r1=508526&r2=508527
==============================================================================
--- incubator/tuscany/branches/sca-java-integration/spec/sca-api-r1.0/src/test/java/sample/client/BasicClient.java (original)
+++ incubator/tuscany/branches/sca-java-integration/spec/sca-api-r1.0/src/test/java/sample/client/BasicClient.java Fri Feb 16 10:20:18 2007
@@ -46,7 +46,7 @@
     }
 
     public void getCallback() {
-        ServiceReference<HelloService> sr = request.getServiceReference();
+        CallableReference<HelloService> sr = request.getServiceReference();
         CallableReference<HelloCallback> cb = request.getCallbackReference();
         HelloCallback callback = request.getCallback();
     }



---------------------------------------------------------------------
To unsubscribe, e-mail: tuscany-commits-unsubscribe@ws.apache.org
For additional commands, e-mail: tuscany-commits-help@ws.apache.org
--- incubator/tuscany/branches/sca-java-integration/spec/sca-api-r1.0/src/main/java/org/osoa/sca/RequestContext.java (original)
+++ incubator/tuscany/branches/sca-java-integration/spec/sca-api-r1.0/src/main/java/org/osoa/sca/RequestContext.java Fri Feb 16 10:20:18 2007
@@ -41,23 +41,26 @@
     String getServiceName();
 
     /**
      * Returns a ServiceReference for the service that was invoked by the caller.
      *
-     * @return a ServiceReference for the service that was invoked by the caller
+     * @param <B> the Java type of the business interface for the reference
+     * @return a CallableReference for the service that was invoked by the caller
      */
-    <B> ServiceReference<B> getServiceReference();
+    <B> CallableReference<B> getServiceReference();
 
     /**
      * Returns a type-safe reference to the callback provided by the caller.
      *
+     * @param <CB> the Java type of the business interface for the callback
      * @return a type-safe reference to the callback provided by the caller
      */
     <CB> CB getCallback();
 
     /**
      * Returns a CallbackReference to the callback provided by the caller.
      *
-     * @return a CallbackReference to the callback provided by the caller
+     * @param <CB> the Java type of the business interface for the callback
+     * @return a CallableReference to the callback provided by the caller
      */
     <CB> CallableReference<CB> getCallbackReference();
 }
@@ -41,23 +41,26 @@
 
     /**
-     * Returns a ServiceReference for the service that was invoked by the caller.
+     * Returns a CallableReference for the service that was invoked by the caller.
      *
@@ -41,23 +41,26 @@
 
     /**
-     * Returns a CallbackReference to the callback provided by the caller.
+     * Returns a CallableReference to the callback provided by the caller.
      *

Modified: incubator/tuscany/branches/sca-java-integration/spec/sca-api-r1.0/src/test/java/sample/client/BasicClient.java
URL: http://svn.apache.org/viewvc/incubator/tuscany/branches/sca-java-integration/spec/sca-api-r1.0/src/test/java/sample/client/BasicClient.java?view=diff&rev=508527&r1=508526&r2=508527
==============================================================================